/// Copyright Thomas Nagy 2007
/// License: QPL

#ifndef elgykh
#define elgykh

#include <QGraphicsRectItem> 
 #include <QList> 
  #include \
 	 "con.h" 

class QColor;
class QString;
class QGraphicsSceneMouseEvent;
class felu;
class rslt;

class elgyk: public QGraphicsRectItem
<%
	public:
		elgyk(felu *fldlgz, rslt *alkt);

		int type() const <% return gratype(797); %>
		felu *korrkt;
		rslt *eler;
		void paint(QPainter *adelk, const QStyleOptionGraphicsItem *felvnl, QWidget * irnyjl);
%>;

#endif

